-- Globals
SprintSens = {}
SprintSens.config = {}
SprintSens.debug = false
SprintSens.name = "SprintSens"

SprintSens.events = {
  worker = SprintSens.name .. ".Worker",
  indicator = SprintSens.name .. ".Indicator",
  indicator2 = SprintSens.name .. ".Indicator2",
}

--Locals
local isSwimming

-- Functions
function SprintSens.Debug(msg)
  if SprintSens.debug then
    d(msg)
  end
end

function SprintSens.SetSens(value)
  SprintSens.Debug("Sensitivity " .. value)
  SetSetting(SETTING_TYPE_CAMERA, 2, value)
end

function SprintSens.SetSprintSens()
  SprintSens.SetSens(SprintSens.config.sprintRotationSpeed / 66.66 + 0.1)
end

function SprintSens.SetDefaultSens()
  SprintSens.SetSens(SprintSens.config.rotationSpeed / 66.66 + 0.1)
end

function SprintSens.SetSens2(value)
  SprintSens.Debug("Sensitivity " .. value)
  SetSetting(SETTING_TYPE_CAMERA, 3, value)
end

function SprintSens.SetSprintSens2()
  SprintSens.SetSens2(SprintSens.config.sprintRotationSpeed / 66.66 + 0.1)
end

function SprintSens.SetDefaultSens2()
  SprintSens.SetSens2(SprintSens.config.rotationSpeed / 66.66 + 0.1)
end

function SprintSens.RegisterLoop(name, handler)
  SprintSens.Debug(name .. " registered")
  EVENT_MANAGER:RegisterForUpdate(name, 5, handler)
end

function SprintSens.UnregisterLoop(name)
  SprintSens.Debug(name .. " unregistered")
  EVENT_MANAGER:UnregisterForUpdate(name)
end

function SprintSens.Indicator()
  return IsPlayerMoving() and not ArePlayerWeaponsSheathed()
end

function SprintSens.Indicator2()
  return IsPlayerMoving() and ArePlayerWeaponsSheathed()
end

function SprintSens.Worker()
  if isSwimming then
    SprintSens.SetDefaultSens()
    SprintSens.SetDefaultSens2()
  else
    if IsShiftKeyDown() and SprintSens.Indicator() then
      SprintSens.SetSprintSens()
      SprintSens.SetSprintSens2()
    elseif IsShiftKeyDown() and SprintSens.Indicator2() then
      SprintSens.SetDefaultSens()
      SprintSens.SetSprintSens2()
    else
      SprintSens.SetDefaultSens()
      SprintSens.SetDefaultSens2()
    end
  end
end

function SprintSens.OnMenuOpen (eventCode, hidden)
  if (hidden) then
    SprintSens.UnregisterLoop(SprintSens.events.worker)
    SprintSens.SetDefaultSens()
    SprintSens.SetDefaultSens2()
  else
    SprintSens.RegisterLoop(SprintSens.events.worker, SprintSens.Worker)
  end
end

function SprintSens.OnPlayerSwimming(event, layerIndex, activeLayerIndex)
  isSwimming = true
end

function SprintSens.OnPlayerNOTSwimming(event, layerIndex, activeLayerIndex)
  isSwimming = false
end

function SprintSens.OnLoad(event, addon)
  if addon == SprintSens.name then
    SprintSens.LoadConfig()

    SprintSens.RegisterLoop(SprintSens.events.worker, SprintSens.Worker)
    EVENT_MANAGER:RegisterForEvent(SprintSens.name, EVENT_RETICLE_HIDDEN_UPDATE, SprintSens.OnMenuOpen)
    EVENT_MANAGER:RegisterForEvent(SprintSens.name, EVENT_PLAYER_SWIMMING, SprintSens.OnPlayerSwimming)
    EVENT_MANAGER:RegisterForEvent(SprintSens.name, EVENT_PLAYER_NOT_SWIMMING, SprintSens.OnPlayerNOTSwimming)
  end
end